@@ -23,7 +23,7 @@ use strict;
 use warnings;
 
 package DUCK;
-my $VERSION        = '0.14.2';
+my $VERSION        = '0.14.4';
 my $COPYRIGHT_YEAR = '2023';
 my $default_user_agent = 'Mozilla/5.0 (X11; Linux x86_64; rv:46.0) '
     . 'Gecko/20100101 Firefox/46.0';
@@ -455,7 +455,7 @@ sub __run_browser {
 
     $curl->setopt(CURLOPT_CERTINFO,        0);
     $curl->setopt(CURLOPT_FOLLOWLOCATION,  1);
-    $curl->setopt(CURLOPT_SSL_CIPHER_LIST, 'ALL');
+    $curl->setopt(CURLOPT_SSL_CIPHER_LIST, 'LEGACY');
     $curl->setopt(CURLOPT_MAXREDIRS,       10);
     $curl->setopt(CURLOPT_TIMEOUT,         60);
     $curl->setopt(CURLOPT_USERAGENT,       $user_agent);
